@@ -9,17 +9,27 @@
     :license: Apache, see LICENSE.txt for more details.
 """
 
+import logging
+log = logging.getLogger("tipfy.ext.jsontemplate")
+
 import os
 
 from tipfy import Tipfy
+
 import jsontemplate
 
 default_config = {
     'templates_dir': 'templates/json',
 }
 
+_cache = {}
 
-def raw_jsontemplate(filename):
+def _mtime(filename):
+    cfg = Tipfy.app.get_config('tipfy.ext.jsontemplate')
+    path = os.path.join(cfg["templates_dir"], filename)
+    return os.path.getmtime(path)
+
+def get_source(filename):
     """ Returns a raw template string.
 
     :param filename:
@@ -36,8 +46,13 @@ def get_template(filename):
     :param filename:
         The template filename relative to the templates directory.
     """
-    
-    return jsontemplate.Template(raw_jsontemplate(filename))
+    t = _cache.get(filename)
+    if t and t._uptodate():
+        return t
+    t = _cache[filename] = jsontemplate.Template(get_source(filename))
+    mtime = _mtime(filename)
+    t._uptodate = lambda: _mtime(filename) == mtime
+    return t
     
 def render_template(filename, **context):
     """Renders a JSON template.
